import { type ReactiveControllerHost } from 'lit';
import { Context } from '../context';
import { type ReadableStoreRecord, type StoreValue } from './types';
/**
 * Helper function to subscribe to an individual store record item for the life of the given
 * `host` element.
 *
 * @example
 * ```ts
 * import { LitElement } from 'lit';
 * import { storeRecordSubscription, mediaStoreContext } from '@vidstack/player';
 *
 * class MyElement extends LitElement {
 *   constructor() {
 *     super();
 *     storeRecordSubscription(this, mediaStoreContext, 'paused', ($value) => {
 *       // ...
 *     });
 *   }
 * }
 * ```
 */
export declare function storeRecordSubscription<StoreRecord extends ReadableStoreRecord, Key extends keyof StoreRecord>(host: ReactiveControllerHost & EventTarget, store: StoreRecord | Context<StoreRecord>, key: Key, onChange: (value: StoreValue<StoreRecord[Key]>) => void): void;
//# sourceMappingURL=storeRecordSubscription.d.ts.map