import { type ReactiveControllerHost } from 'lit';
import { Context } from '../context';
import { type ReadableStore } from './types';
/**
 * Helper function to subscribe to a store for the life of the given `host` element, meaning
 * when it's disconnected from the DOM, the subscription is destroyed.
 *
 * @example
 * ```ts
 * import { LitElement } from 'lit';
 * import { storeSubscription } from '@vidstack/player';
 *
 * class MyElement extends LitElement {
 *   constructor() {
 *     super();
 *     storeSubscription(this, <<store>>, ($value) => {
 *       // ...
 *     });
 *   }
 * }
 * ```
 */
export declare function storeSubscription<T>(host: ReactiveControllerHost & EventTarget, store: ReadableStore<T> | Context<ReadableStore<T>>, onChange: (value: T) => void): void;
//# sourceMappingURL=storeSubscription.d.ts.map