/** Callback to inform of a value updates. */
export declare type StoreSubscriber<T> = (value: T) => void;
/** Unsubscribes from value updates. */
export declare type StoreUnsubscriber = () => void;
/** Callback to update a value. */
export declare type StoreUpdater<T> = (value: T) => T;
/** Cleanup logic callback. */
export declare type StoreInvalidator<T> = (value?: T) => void;
/** Start and stop notification callbacks. */
export declare type StoreStartStopNotifier<T> = (set: StoreSubscriber<T>) => StoreUnsubscriber | void;
/** Readable interface for subscribing. */
export declare type ReadableStore<T> = {
    initialValue: T | undefined;
    /**
     * Subscribe on value changes.
     * @param run subscription callback
     * @param invalidate cleanup callback
     */
    subscribe(this: void, run: StoreSubscriber<T>, invalidate?: StoreInvalidator<T>): StoreUnsubscriber;
};
/** Writable interface for both updating and subscribing. */
export declare type WritableStore<T> = ReadableStore<T> & {
    /**
     * Set value and inform subscribers.
     * @param value to set
     */
    set(this: void, value: T): void;
    /**
     * Update value using callback and inform subscribers.
     * @param updater callback
     */
    update(this: void, updater: StoreUpdater<T>): void;
};
/** Pair of subscriber and invalidator. */
export declare type SubscribeInvalidateTuple<T> = [StoreSubscriber<T>, StoreInvalidator<T>];
export declare type ReadableStoreRecord = {
    [prop: string]: ReadableStore<any>;
};
export declare type WritableStoreRecord = {
    [prop: string]: WritableStore<any>;
};
export declare type StoreValue<T> = T extends ReadableStore<infer U> ? U : never;
/** One or more `Readable`s. */
export declare type Stores = ReadableStore<any> | [ReadableStore<any>, ...Array<ReadableStore<any>>] | Array<ReadableStore<any>>;
/** One or more values from `Readable` stores. */
export declare type StoresValues<T> = T extends ReadableStore<infer U> ? U : {
    [K in keyof T]: T[K] extends ReadableStore<infer U> ? U : never;
};
//# sourceMappingURL=types.d.ts.map