import { ArrayElement } from '../helper-types';
export declare function keysOf<T>(obj: T): (keyof T)[];
/**
 * Creates an object composed of the picked `object` properties.
 */
export declare function pick<T>(obj: T, keys: (keyof T)[]): Pick<T, ArrayElement<typeof keys>>;
/**
 * The opposite of `pick`; this method creates an `object` composed of the own and inherited
 * enumerable property paths of object that are not omitted.
 */
export declare function omit<T>(obj: T, keys: (keyof T)[]): Omit<T, ArrayElement<typeof keys>>;
/**
 * Whether the given `prop` is a direct property of the given object (`obj`).
 */
export declare const hasOwnProperty: <T>(obj: T, prop: keyof T) => prop is keyof T;
/**
 * Sorts an array of objects by a given property known as the sort key.
 */
export declare const sortObjectsBy: <T>(objects: T[], sortKey: keyof T) => T[];
//# sourceMappingURL=object.d.ts.map