export declare const IS_CLIENT: boolean;
export declare const UA: string;
export declare const IS_IOS: boolean;
export declare const IS_ANDROID: boolean;
export declare const IS_MOBILE: boolean;
export declare const IS_IPHONE: boolean;
export declare const IS_FIREFOX: boolean;
export declare const IS_CHROME: boolean;
export declare const IS_SAFARI: boolean;
export declare const ORIGIN: string | undefined;
/**
 * Returns the current version of Safari. Defaults to `0` if unknown.
 */
export declare function currentSafariVersion(): number;
/**
 * Checks if a video player can enter fullscreen.
 *
 * @link https://developer.apple.com/documentation/webkitjs/htmlvideoelement/1633500-webkitenterfullscreen
 */
export declare function canFullscreenVideo(): boolean;
/**
 * Checks whether the `IntersectionObserver` API is available.
 */
export declare function canObserveIntersection(): boolean;
/**
 * Checks if the ScreenOrientation API is available.
 *
 * @link https://developer.mozilla.org/en-US/docs/Web/API/Screen/orientation
 */
export declare function canOrientScreen(): boolean;
/**
 * Checks if the screen orientation can be changed.
 *
 * @link https://developer.mozilla.org/en-US/docs/Web/API/Screen/orientation
 */
export declare function canRotateScreen(): boolean;
/**
 * Reduced motion iOS & MacOS setting.
 *
 * @link https://webkit.org/blog/7551/responsive-design-for-motion/
 */
export declare function isReducedMotionPreferred(): boolean;
/**
 * Checks if the native HTML5 video player can play HLS.
 */
export declare function canPlayHLSNatively(): boolean;
/**
 * Checks if the native HTML5 video player can enter picture-in-picture (PIP) mode when using
 * the Chrome browser.
 *
 * @link  https://developers.google.com/web/updates/2018/10/watch-video-using-picture-in-picture
 */
export declare function canUsePiPInChrome(): boolean;
/**
 * Checks if the native HTML5 video player can enter picture-in-picture (PIP) mode when using
 * the desktop Safari browser, iOS Safari appears to "support" PiP through the check, however PiP
 * does not function.
 *
 * @link https://developer.apple.com/documentation/webkitjs/adding_picture_in_picture_to_your_safari_media_controls
 */
export declare function canUsePiPInSafari(): boolean;
/**
 * Checks if the native HTML5 video player can enter PIP.
 */
export declare function canUsePiP(): boolean;
/**
 * To detect autoplay, we create a video element and call play on it, if it is `paused` after
 * a `play()` call, autoplay is supported. Although this unintuitive, it works across browsers
 * and is currently the lightest way to detect autoplay without using a data source.
 *
 * @param muted
 * @param playsinline
 * @link https://github.com/ampproject/amphtml/blob/9bc8756536956780e249d895f3e1001acdee0bc0/src/utils/video.js#L25
 */
export declare function canAutoplay(muted?: boolean, playsinline?: boolean): Promise<boolean>;
/**
 * @link https://github.com/video-dev/hls.js/blob/master/src/is-supported.ts
 */
export declare function getMediaSource(): typeof MediaSource | undefined;
/**
 * @link https://github.com/video-dev/hls.js/blob/master/src/is-supported.ts
 */
export declare function getSourceBuffer(): typeof SourceBuffer | undefined;
/**
 * Whether `hls.js` is supported in this environment.
 *
 * @link https://github.com/video-dev/hls.js/blob/master/src/is-supported.ts
 */
export declare function isHlsjsSupported(): boolean;
//# sourceMappingURL=support.d.ts.map